@@ -1230,7 +1230,8 @@ class SchemaView(object):
             induced_slot.alias = underscore(slot_name)
         for c in self.all_classes().values():
             if induced_slot.name in c.slots or induced_slot.name in c.attributes:
-                induced_slot.domain_of.append(c.name)
+                if c.name not in induced_slot.domain_of:
+                    induced_slot.domain_of.append(c.name)
         return deepcopy(induced_slot)
 
     @lru_cache()
@@ -1452,21 +1453,20 @@ class SchemaView(object):
                         enum_slots.append(slot_definition)
         return enum_slots
 
-    def get_classes_modifying_slot(self, slot_name: SLOT_NAME = None) -> List[ClassDefinition]:
+    def get_classes_modifying_slot(self, slot: SlotDefinition) -> List[ClassDefinition]:
         """Get all ClassDefinitions that modify a given slot.
 
         :param slot_name: slot in consideration
         :return: list of ClassDefinitions modifying the slot of interest
         """
-        # slot_classes = [c for c in self.all_classes().values() if c.slot_usage == slot_name]
-        # slot_classes = [c for c in self.all_classes().values()]
-        slot_classes = []
+        modifying_classes = []
         for class_definition in self.all_classes().values():
             if class_definition.slot_usage:
                 for slot_definition in class_definition.slot_usage.values():
-                    if slot_definition.name == slot_name:
-                        slot_classes.append(class_definition)
-        return slot_classes
+                    if slot_definition.name == slot.name:
+                        modifying_classes.append(class_definition.name)
+
+        return modifying_classes
 
     def is_slot_percent_encoded(self, slot: SlotDefinitionName) -> bool:
         """
@@ -1592,7 +1592,7 @@ class SchemaView(object):
         :param type_name: type to be deleted
         :return:
         """
-        del self.schema.typees[type_name]
+        del self.schema.types[type_name]
         self.set_modified()
 
     def delete_subset(self, subset_name: SubsetDefinitionName) -> None:
@@ -1723,4 +1723,4 @@ class SchemaView(object):
             derived_schema.subsets[subset.name] = subset
         for enum in [deepcopy(e) for e in self.all_enums().values()]:
             derived_schema.enums[enum.name] = enum
-        return derived_schema
+        return derived_schema
\ No newline at end of file
